.. currentmodule:: abjad.tools.instrumenttools

transpose_from_sounding_pitch_to_written_pitch
==============================================

.. autofunction:: transpose_from_sounding_pitch_to_written_pitch
